@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -18,10 +18,10 @@
 
 from io import BytesIO
 
-from ..object import Object
+from ..tl_object import TLObject
 
 
-class Bytes(Object):
+class Bytes(TLObject):
     @staticmethod
     def read(b: BytesIO, *args) -> bytes:
         length = int.from_bytes(b.read(1), "little")
@@ -48,7 +48,7 @@ class Bytes(Object):
         else:
             return (
                 bytes([254])
-                + int.to_bytes(length, 3, "little")
+                + length.to_bytes(3, "little")
                 + value
                 + bytes(-length % 4)
             )
