@@ -20,10 +20,17 @@ import logging
 import threading
 from collections import OrderedDict
 from queue import Queue
-from threading import Thread
+from threading import Thread, Lock
 
 import pyrogram
-from pyrogram.api import types
+from pyrogram.api.types import (
+    UpdateNewMessage, UpdateNewChannelMessage, UpdateNewScheduledMessage,
+    UpdateEditMessage, UpdateEditChannelMessage,
+    UpdateDeleteMessages, UpdateDeleteChannelMessages,
+    UpdateBotCallbackQuery, UpdateInlineBotCallbackQuery,
+    UpdateUserStatus, UpdateBotInlineQuery, UpdateMessagePoll
+)
+from . import utils
 from ..handlers import (
     CallbackQueryHandler, MessageHandler, DeletedMessagesHandler,
     UserStatusHandler, RawUpdateHandler, InlineQueryHandler, PollHandler
@@ -34,23 +41,24 @@ log = logging.getLogger(__name__)
 
 class Dispatcher:
     NEW_MESSAGE_UPDATES = (
-        types.UpdateNewMessage,
-        types.UpdateNewChannelMessage
+        UpdateNewMessage,
+        UpdateNewChannelMessage,
+        UpdateNewScheduledMessage
     )
 
     EDIT_MESSAGE_UPDATES = (
-        types.UpdateEditMessage,
-        types.UpdateEditChannelMessage
+        UpdateEditMessage,
+        UpdateEditChannelMessage,
     )
 
     DELETE_MESSAGES_UPDATES = (
-        types.UpdateDeleteMessages,
-        types.UpdateDeleteChannelMessages
+        UpdateDeleteMessages,
+        UpdateDeleteChannelMessages
     )
 
     CALLBACK_QUERY_UPDATES = (
-        types.UpdateBotCallbackQuery,
-        types.UpdateInlineBotCallbackQuery
+        UpdateBotCallbackQuery,
+        UpdateInlineBotCallbackQuery
     )
 
     MESSAGE_UPDATES = NEW_MESSAGE_UPDATES + EDIT_MESSAGE_UPDATES
@@ -60,28 +68,37 @@ class Dispatcher:
         self.workers = workers
 
         self.workers_list = []
+        self.locks_list = []
+
         self.updates_queue = Queue()
         self.groups = OrderedDict()
 
         self.update_parsers = {
             Dispatcher.MESSAGE_UPDATES:
-                lambda upd, usr, cht: (pyrogram.Message._parse(self.client, upd.message, usr, cht), MessageHandler),
+                lambda upd, usr, cht: (
+                    pyrogram.Message._parse(
+                        self.client,
+                        upd.message,
+                        usr,
+                        cht,
+                        isinstance(upd, UpdateNewScheduledMessage)
+                    ),
+                    MessageHandler
+                ),
 
             Dispatcher.DELETE_MESSAGES_UPDATES:
-                lambda upd, usr, cht: (pyrogram.Messages._parse_deleted(self.client, upd), DeletedMessagesHandler),
+                lambda upd, usr, cht: (utils.parse_deleted_messages(self.client, upd), DeletedMessagesHandler),
 
             Dispatcher.CALLBACK_QUERY_UPDATES:
                 lambda upd, usr, cht: (pyrogram.CallbackQuery._parse(self.client, upd, usr), CallbackQueryHandler),
 
-            (types.UpdateUserStatus,):
-                lambda upd, usr, cht: (
-                    pyrogram.UserStatus._parse(self.client, upd.status, upd.user_id), UserStatusHandler
-                ),
+            (UpdateUserStatus,):
+                lambda upd, usr, cht: (pyrogram.User._parse_user_status(self.client, upd), UserStatusHandler),
 
-            (types.UpdateBotInlineQuery,):
+            (UpdateBotInlineQuery,):
                 lambda upd, usr, cht: (pyrogram.InlineQuery._parse(self.client, upd, usr), InlineQueryHandler),
 
-            (types.UpdateMessagePoll,):
+            (UpdateMessagePoll,):
                 lambda upd, usr, cht: (pyrogram.Poll._parse_update(self.client, upd), PollHandler)
         }
 
@@ -89,10 +106,13 @@ class Dispatcher:
 
     def start(self):
         for i in range(self.workers):
+            self.locks_list.append(Lock())
+
             self.workers_list.append(
                 Thread(
                     target=self.update_worker,
-                    name="UpdateWorker#{}".format(i + 1)
+                    name="UpdateWorker#{}".format(i + 1),
+                    args=(self.locks_list[-1],)
                 )
             )
 
@@ -106,21 +126,37 @@ class Dispatcher:
             worker.join()
 
         self.workers_list.clear()
+        self.locks_list.clear()
+        self.groups.clear()
 
     def add_handler(self, handler, group: int):
-        if group not in self.groups:
-            self.groups[group] = []
-            self.groups = OrderedDict(sorted(self.groups.items()))
+        for lock in self.locks_list:
+            lock.acquire()
 
-        self.groups[group].append(handler)
+        try:
+            if group not in self.groups:
+                self.groups[group] = []
+                self.groups = OrderedDict(sorted(self.groups.items()))
+
+            self.groups[group].append(handler)
+        finally:
+            for lock in self.locks_list:
+                lock.release()
 
     def remove_handler(self, handler, group: int):
-        if group not in self.groups:
-            raise ValueError("Group {} does not exist. Handler was not removed.".format(group))
+        for lock in self.locks_list:
+            lock.acquire()
 
-        self.groups[group].remove(handler)
+        try:
+            if group not in self.groups:
+                raise ValueError("Group {} does not exist. Handler was not removed.".format(group))
 
-    def update_worker(self):
+            self.groups[group].remove(handler)
+        finally:
+            for lock in self.locks_list:
+                lock.release()
+
+    def update_worker(self, lock):
         name = threading.current_thread().name
         log.debug("{} started".format(name))
 
@@ -140,29 +176,35 @@ class Dispatcher:
                     else (None, type(None))
                 )
 
-                for group in self.groups.values():
-                    for handler in group:
-                        args = None
+                with lock:
+                    for group in self.groups.values():
+                        for handler in group:
+                            args = None
 
-                        if isinstance(handler, handler_type):
-                            if handler.check(parsed_update):
-                                args = (parsed_update,)
-                        elif isinstance(handler, RawUpdateHandler):
-                            args = (update, users, chats)
+                            if isinstance(handler, handler_type):
+                                try:
+                                    if handler.check(parsed_update):
+                                        args = (parsed_update,)
+                                except Exception as e:
+                                    log.error(e, exc_info=True)
+                                    continue
 
-                        if args is None:
-                            continue
+                            elif isinstance(handler, RawUpdateHandler):
+                                args = (update, users, chats)
 
-                        try:
-                            handler.callback(self.client, *args)
-                        except pyrogram.StopPropagation:
-                            raise
-                        except pyrogram.ContinuePropagation:
-                            continue
-                        except Exception as e:
-                            log.error(e, exc_info=True)
+                            if args is None:
+                                continue
 
-                        break
+                            try:
+                                handler.callback(self.client, *args)
+                            except pyrogram.StopPropagation:
+                                raise
+                            except pyrogram.ContinuePropagation:
+                                continue
+                            except Exception as e:
+                                log.error(e, exc_info=True)
+
+                            break
             except pyrogram.StopPropagation:
                 pass
             except Exception as e:
