@@ -44,20 +44,28 @@ class GetChatMember(BaseClient):
         Returns:
             :obj:`ChatMember`: On success, a chat member is returned.
 
-        Raises:
-            RPCError: In case of a Telegram RPC error.
+        Example:
+            .. code-block:: python
+
+                dan = app.get_chat_member("pyrogramchat", "haskell")
+                print(dan)
         """
         chat = self.resolve_peer(chat_id)
         user = self.resolve_peer(user_id)
 
         if isinstance(chat, types.InputPeerChat):
-            full_chat = self.send(
+            r = self.send(
                 functions.messages.GetFullChat(
                     chat_id=chat.chat_id
                 )
             )
 
-            for member in pyrogram.ChatMembers._parse(self, full_chat).chat_members:
+            members = r.full_chat.participants.participants
+            users = {i.id: i for i in r.users}
+
+            for member in members:
+                member = pyrogram.ChatMember._parse(self, member, users)
+
                 if isinstance(user, types.InputPeerSelf):
                     if member.user.is_self:
                         return member
