@@ -24,19 +24,28 @@ from ...ext import BaseClient
 
 
 class AddContacts(BaseClient):
-    def add_contacts(self,
-                     contacts: List["pyrogram.InputPhoneContact"]):
-        """Use this method to add contacts to your Telegram address book.
+    def add_contacts(
+        self,
+        contacts: List["pyrogram.InputPhoneContact"]
+    ):
+        """Add contacts to your Telegram address book.
 
-        Args:
-            contacts (List of :obj:`InputPhoneContact <pyrogram.InputPhoneContact>`):
+        Parameters:
+            contacts (List of :obj:`InputPhoneContact`):
                 The contact list to be added
 
         Returns:
-            On success, the added contacts are returned.
+            :obj:`types.contacts.ImportedContacts`
 
-        Raises:
-            :class:`Error <pyrogram.Error>` in case of a Telegram RPC error.
+        Example:
+            .. code-block:: python
+
+                from pyrogram import InputPhoneContact
+
+                app.add_contacts([
+                    InputPhoneContact("39123456789", "Foo"),
+                    InputPhoneContact("38987654321", "Bar"),
+                    InputPhoneContact("01234567891", "Baz")])
         """
         imported_contacts = self.send(
             functions.contacts.ImportContacts(
