@@ -23,19 +23,15 @@ from pyrogram.client.ext import BaseClient
 
 
 class DeleteMessages(BaseClient):
-    def delete_messages(self,
-                        chat_id: Union[int, str],
-                        message_ids: Iterable[int],
-                        revoke: bool = True) -> bool:
-        """Use this method to delete messages, including service messages, with the following limitations:
+    def delete_messages(
+        self,
+        chat_id: Union[int, str],
+        message_ids: Iterable[int],
+        revoke: bool = True
+    ) -> bool:
+        """Delete messages, including service messages.
 
-        - A message can only be deleted if it was sent less than 48 hours ago.
-        - Users can delete outgoing messages in groups and supergroups.
-        - Users granted *can_post_messages* permissions can delete outgoing messages in channels.
-        - If the user is an administrator of a group, it can delete any message there.
-        - If the user has *can_delete_messages* permission in a supergroup or a channel, it can delete any message there.
-
-        Args:
+        Parameters:
             chat_id (``int`` | ``str``):
                 Unique identifier (int) or username (str) of the target chat.
                 For your personal cloud (Saved Messages) you can simply use "me" or "self".
@@ -52,27 +48,38 @@ class DeleteMessages(BaseClient):
                 Defaults to True.
 
         Returns:
-            True on success.
+            ``bool``: True on success, False otherwise.
 
-        Raises:
-            :class:`Error <pyrogram.Error>` in case of a Telegram RPC error.
+        Example:
+            .. code-block:: python
+
+                # Delete one message
+                app.delete_messages(chat_id, message_id)
+
+                # Delete multiple messages at once
+                app.delete_messages(chat_id, list_of_message_ids)
+
+                # Delete messages only on your side (without revoking)
+                app.delete_messages(chat_id, message_id, revoke=False)
         """
         peer = self.resolve_peer(chat_id)
         message_ids = list(message_ids) if not isinstance(message_ids, int) else [message_ids]
 
         if isinstance(peer, types.InputPeerChannel):
-            self.send(
+            r = self.send(
                 functions.channels.DeleteMessages(
                     channel=peer,
                     id=message_ids
                 )
             )
         else:
-            self.send(
+            r = self.send(
                 functions.messages.DeleteMessages(
                     id=message_ids,
                     revoke=revoke or None
                 )
             )
 
-        return True
+        # Deleting messages you don't have right onto, won't raise any error.
+        # Check for pts_count, which is 0 in case deletes fail.
+        return bool(r.pts_count)
