@@ -17,7 +17,10 @@
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
 import binascii
+import os
 import struct
+import time
+from datetime import datetime
 from threading import Event
 from typing import Union
 
@@ -25,12 +28,15 @@ import pyrogram
 from pyrogram.client.ext import BaseClient, FileData, utils
 from pyrogram.errors import FileIdInvalid
 
+DEFAULT_DOWNLOAD_DIR = "downloads/"
+
 
 class DownloadMedia(BaseClient):
     def download_media(
         self,
         message: Union["pyrogram.Message", str],
-        file_name: str = "",
+        file_ref: str = None,
+        file_name: str = DEFAULT_DOWNLOAD_DIR,
         block: bool = True,
         progress: callable = None,
         progress_args: tuple = ()
@@ -42,6 +48,10 @@ class DownloadMedia(BaseClient):
                 Pass a Message containing the media, the media itself (message.audio, message.video, ...) or
                 the file id as string.
 
+            file_ref (``str``, *optional*):
+                A valid file reference obtained by a recently fetched media message.
+                To be used in combination with a file id in case a file reference is needed.
+
             file_name (``str``, *optional*):
                 A custom *file_name* to be used instead of the one provided by Telegram.
                 By default, all files are downloaded in the *downloads* folder in your working directory.
@@ -52,24 +62,23 @@ class DownloadMedia(BaseClient):
                 Blocks the code execution until the file has been downloaded.
                 Defaults to True.
 
-            progress (``callable``):
-                Pass a callback function to view the download progress.
-                The function must take *(client, current, total, \*args)* as positional arguments (look at the section
-                below for a detailed description).
+            progress (``callable``, *optional*):
+                Pass a callback function to view the file transmission progress.
+                The function must take *(current, total)* as positional arguments (look at Other Parameters below for a
+                detailed description) and will be called back each time a new file chunk has been successfully
+                transmitted.
 
-            progress_args (``tuple``):
-                Extra custom arguments for the progress callback function. Useful, for example, if you want to pass
-                a chat_id and a message_id in order to edit a message with the updated progress.
+            progress_args (``tuple``, *optional*):
+                Extra custom arguments for the progress callback function.
+                You can pass anything you need to be available in the progress callback scope; for example, a Message
+                object or a Client instance in order to edit the message with the updated progress status.
 
         Other Parameters:
-            client (:obj:`Client`):
-                The Client itself, useful when you want to call other API methods inside the callback function.
-
             current (``int``):
-                The amount of bytes downloaded so far.
+                The amount of bytes transmitted so far.
 
             total (``int``):
-                The size of the file.
+                The total size of the file.
 
             *args (``tuple``, *optional*):
                 Extra custom arguments as defined in the *progress_args* parameter.
@@ -80,12 +89,21 @@ class DownloadMedia(BaseClient):
             the download failed or was deliberately stopped with :meth:`~Client.stop_transmission`, None is returned.
 
         Raises:
-            RPCError: In case of a Telegram RPC error.
-            ``ValueError`` if the message doesn't contain any downloadable media
+            ValueError: if the message doesn't contain any downloadable media
+
+        Example:
+            .. code-block:: python
+
+                # Download from Message
+                app.download_media(message)
+
+                # Download from file id
+                app.download_media("CAADBAADyg4AAvLQYAEYD4F7vcZ43AI")
         """
         error_message = "This message doesn't contain any downloadable media"
         available_media = ("audio", "document", "photo", "sticker", "animation", "video", "voice", "video_note")
 
+        media_file_name = None
         file_size = None
         mime_type = None
         date = None
@@ -105,41 +123,44 @@ class DownloadMedia(BaseClient):
             file_id_str = media
         else:
             file_id_str = media.file_id
-            file_name = getattr(media, "file_name", "")
+            media_file_name = getattr(media, "file_name", "")
             file_size = getattr(media, "file_size", None)
             mime_type = getattr(media, "mime_type", None)
             date = getattr(media, "date", None)
+            file_ref = getattr(media, "file_ref", None)
 
         data = FileData(
-            file_name=file_name,
+            file_name=media_file_name,
             file_size=file_size,
             mime_type=mime_type,
-            date=date
+            date=date,
+            file_ref=file_ref
         )
 
         def get_existing_attributes() -> dict:
             return dict(filter(lambda x: x[1] is not None, data.__dict__.items()))
 
         try:
-            decoded = utils.decode(file_id_str)
+            decoded = utils.decode_file_id(file_id_str)
             media_type = decoded[0]
 
             if media_type == 1:
-                unpacked = struct.unpack("<iiqqib", decoded)
-                dc_id, peer_id, volume_id, local_id, is_big = unpacked[1:]
+                unpacked = struct.unpack("<iiqqqiiiqi", decoded)
+                dc_id, photo_id, _, volume_id, size_type, peer_id, _, peer_access_hash, local_id = unpacked[1:]
 
                 data = FileData(
                     **get_existing_attributes(),
                     media_type=media_type,
                     dc_id=dc_id,
                     peer_id=peer_id,
+                    peer_access_hash=peer_access_hash,
                     volume_id=volume_id,
                     local_id=local_id,
-                    is_big=bool(is_big)
+                    is_big=size_type == 3
                 )
             elif media_type in (0, 2, 14):
-                unpacked = struct.unpack("<iiqqc", decoded)
-                dc_id, document_id, access_hash, thumb_size = unpacked[1:]
+                unpacked = struct.unpack("<iiqqqiiii", decoded)
+                dc_id, document_id, access_hash, volume_id, _, _, thumb_size, local_id = unpacked[1:]
 
                 data = FileData(
                     **get_existing_attributes(),
@@ -147,7 +168,7 @@ class DownloadMedia(BaseClient):
                     dc_id=dc_id,
                     document_id=document_id,
                     access_hash=access_hash,
-                    thumb_size=thumb_size.decode()
+                    thumb_size=chr(thumb_size)
                 )
             elif media_type in (3, 4, 5, 8, 9, 10, 13):
                 unpacked = struct.unpack("<iiqq", decoded)
@@ -168,7 +189,41 @@ class DownloadMedia(BaseClient):
         done = Event()
         path = [None]
 
-        self.download_queue.put((data, file_name, done, progress, progress_args, path))
+        directory, file_name = os.path.split(file_name)
+        file_name = file_name or data.file_name or ""
+
+        if not os.path.isabs(file_name):
+            directory = self.PARENT_DIR / (directory or DEFAULT_DOWNLOAD_DIR)
+
+        media_type_str = self.MEDIA_TYPE_ID[data.media_type]
+
+        if not file_name:
+            guessed_extension = self.guess_extension(data.mime_type)
+
+            if data.media_type in (0, 1, 2, 14):
+                extension = ".jpg"
+            elif data.media_type == 3:
+                extension = guessed_extension or ".ogg"
+            elif data.media_type in (4, 10, 13):
+                extension = guessed_extension or ".mp4"
+            elif data.media_type == 5:
+                extension = guessed_extension or ".zip"
+            elif data.media_type == 8:
+                extension = guessed_extension or ".webp"
+            elif data.media_type == 9:
+                extension = guessed_extension or ".mp3"
+            else:
+                extension = ".unknown"
+
+            file_name = "{}_{}_{}{}".format(
+                media_type_str,
+                datetime.fromtimestamp(data.date or time.time()).strftime("%Y-%m-%d_%H-%M-%S"),
+                self.rnd_id(),
+                extension
+            )
+
+        # Cast to string because Path objects aren't supported by Python 3.5
+        self.download_queue.put((data, str(directory), str(file_name), done, progress, progress_args, path))
 
         if block:
             done.wait()
