@@ -18,16 +18,19 @@
 
 import logging
 import time
-from typing import Union, Iterable
+from typing import Union, Iterable, List
 
 import pyrogram
 from pyrogram.api import functions, types
 from pyrogram.errors import FloodWait
-from ...ext import BaseClient
+from ...ext import BaseClient, utils
 
 log = logging.getLogger(__name__)
 
 
+# TODO: Rewrite using a flag for replied messages and have message_ids non-optional
+
+
 class GetMessages(BaseClient):
     def get_messages(
         self,
@@ -35,11 +38,12 @@ class GetMessages(BaseClient):
         message_ids: Union[int, Iterable[int]] = None,
         reply_to_message_ids: Union[int, Iterable[int]] = None,
         replies: int = 1
-    ) -> Union["pyrogram.Message", "pyrogram.Messages"]:
-        """Use this method to get one or more messages that belong to a specific chat.
+    ) -> Union["pyrogram.Message", List["pyrogram.Message"]]:
+        """Get one or more messages from a chat by using message identifiers.
+
         You can retrieve up to 200 messages at once.
 
-        Args:
+        Parameters:
             chat_id (``int`` | ``str``):
                 Unique identifier (int) or username (str) of the target chat.
                 For your personal cloud (Saved Messages) you can simply use "me" or "self".
@@ -55,15 +59,35 @@ class GetMessages(BaseClient):
                 If *message_ids* is set, this argument will be ignored.
 
             replies (``int``, *optional*):
-                The number of subsequent replies to get for each message. Defaults to 1.
+                The number of subsequent replies to get for each message.
+                Pass 0 for no reply at all or -1 for unlimited replies.
+                Defaults to 1.
 
         Returns:
-            On success and in case *message_ids* or *reply_to_message_ids* was an iterable, the returned value will be a
-            :obj:`Messages <pyrogram.Messages>` even if a list contains just one element. Otherwise, if *message_ids* or
-            *reply_to_message_ids* was an integer, the single requested :obj:`Message <pyrogram.Message>` is returned.
+            :obj:`Message` | List of :obj:`Message`: In case *message_ids* was an integer, the single requested message is
+            returned, otherwise, in case *message_ids* was an iterable, the returned value will be a list of messages,
+            even if such iterable contained just a single element.
+
+        Example:
+            .. code-block:: python
+
+                # Get one message
+                app.get_messages("pyrogramchat", 51110)
+
+                # Get more than one message (list of messages)
+                app.get_messages("pyrogramchat", [44625, 51110])
+
+                # Get message by ignoring any replied-to message
+                app.get_messages(chat_id, message_id, replies=0)
+
+                # Get message with all chained replied-to messages
+                app.get_messages(chat_id, message_id, replies=-1)
+
+                # Get the replied-to message of a message
+                app.get_messages(chat_id, reply_to_message_ids=message_id)
 
         Raises:
-            :class:`RPCError <pyrogram.RPCError>` in case of a Telegram RPC error.
+            ValueError: In case of invalid arguments.
         """
         ids, ids_type = (
             (message_ids, types.InputMessageID) if message_ids
@@ -72,7 +96,7 @@ class GetMessages(BaseClient):
         )
 
         if ids is None:
-            raise ValueError("No argument supplied")
+            raise ValueError("No argument supplied. Either pass message_ids or reply_to_message_ids")
 
         peer = self.resolve_peer(chat_id)
 
@@ -80,6 +104,9 @@ class GetMessages(BaseClient):
         ids = list(ids) if is_iterable else [ids]
         ids = [ids_type(id=i) for i in ids]
 
+        if replies < 0:
+            replies = (1 << 31) - 1
+
         if isinstance(peer, types.InputPeerChannel):
             rpc = functions.channels.GetMessages(channel=peer, id=ids)
         else:
@@ -94,6 +121,6 @@ class GetMessages(BaseClient):
             else:
                 break
 
-        messages = pyrogram.Messages._parse(self, r, replies=replies)
+        messages = utils.parse_messages(self, r, replies=replies)
 
-        return messages if is_iterable else messages.messages[0]
+        return messages if is_iterable else messages[0]
