@@ -30,15 +30,17 @@ class SendAnimation(BaseClient):
         self,
         chat_id: Union[int, str],
         animation: str,
+        file_ref: str = None,
         caption: str = "",
         unsave: bool = False,
-        parse_mode: str = "",
+        parse_mode: Union[str, None] = object,
         duration: int = 0,
         width: int = 0,
         height: int = 0,
         thumb: str = None,
         disable_notification: bool = None,
         reply_to_message_id: int = None,
+        schedule_date: int = None,
         reply_markup: Union[
             "pyrogram.InlineKeyboardMarkup",
             "pyrogram.ReplyKeyboardMarkup",
@@ -62,16 +64,23 @@ class SendAnimation(BaseClient):
                 pass an HTTP URL as a string for Telegram to get an animation from the Internet, or
                 pass a file path as string to upload a new animation that exists on your local machine.
 
+            file_ref (``str``, *optional*):
+                A valid file reference obtained by a recently fetched media message.
+                To be used in combination with a file id in case a file reference is needed.
+
             caption (``str``, *optional*):
                 Animation caption, 0-1024 characters.
 
             unsave (``bool``, *optional*):
-                By default, the server will save into your own collection any new animation GIF you send.
+                By default, the server will save into your own collection any new animation you send.
                 Pass True to automatically unsave the sent animation. Defaults to False.
 
             parse_mode (``str``, *optional*):
-                Pass "markdown" or "html" if you want Telegram apps to show bold, italic, fixed-width text or inline
-                URLs in your caption. Defaults to "markdown".
+                By default, texts are parsed using both Markdown and HTML styles.
+                You can combine both syntaxes together.
+                Pass "markdown" or "md" to enable Markdown-style parsing only.
+                Pass "html" to enable HTML-style parsing only.
+                Pass None to completely disable style parsing.
 
             duration (``int``, *optional*):
                 Duration of sent animation in seconds.
@@ -95,28 +104,30 @@ class SendAnimation(BaseClient):
             reply_to_message_id (``int``, *optional*):
                 If the message is a reply, ID of the original message.
 
+            schedule_date (``int``, *optional*):
+                Date when the message will be automatically sent. Unix time.
+
             reply_markup (:obj:`InlineKeyboardMarkup` | :obj:`ReplyKeyboardMarkup` | :obj:`ReplyKeyboardRemove` | :obj:`ForceReply`, *optional*):
                 Additional interface options. An object for an inline keyboard, custom reply keyboard,
                 instructions to remove reply keyboard or to force a reply from the user.
 
             progress (``callable``, *optional*):
-                Pass a callback function to view the upload progress.
-                The function must take *(client, current, total, \*args)* as positional arguments (look at the section
-                below for a detailed description).
+                Pass a callback function to view the file transmission progress.
+                The function must take *(current, total)* as positional arguments (look at Other Parameters below for a
+                detailed description) and will be called back each time a new file chunk has been successfully
+                transmitted.
 
             progress_args (``tuple``, *optional*):
-                Extra custom arguments for the progress callback function. Useful, for example, if you want to pass
-                a chat_id and a message_id in order to edit a message with the updated progress.
+                Extra custom arguments for the progress callback function.
+                You can pass anything you need to be available in the progress callback scope; for example, a Message
+                object or a Client instance in order to edit the message with the updated progress status.
 
         Other Parameters:
-            client (:obj:`Client`):
-                The Client itself, useful when you want to call other API methods inside the callback function.
-
             current (``int``):
-                The amount of bytes uploaded so far.
+                The amount of bytes transmitted so far.
 
             total (``int``):
-                The size of the file.
+                The total size of the file.
 
             *args (``tuple``, *optional*):
                 Extra custom arguments as defined in the *progress_args* parameter.
@@ -126,11 +137,25 @@ class SendAnimation(BaseClient):
             :obj:`Message` | ``None``: On success, the sent animation message is returned, otherwise, in case the upload
             is deliberately stopped with :meth:`~Client.stop_transmission`, None is returned.
 
-        Raises:
-            RPCError: In case of a Telegram RPC error.
+        Example:
+            .. code-block:: python
+
+                # Send animation by uploading from local file
+                app.send_animation("me", "animation.gif")
+
+                # Add caption to the animation
+                app.send_animation("me", "animation.gif", caption="cat")
+
+                # Unsave the animation once is sent
+                app.send_animation("me", "animation.gif", unsave=True)
+
+                # Keep track of the progress while uploading
+                def progress(current, total):
+                    print("{:.1f}%".format(current * 100 / total))
+
+                app.send_animation("me", "animation.gif", progress=progress)
         """
         file = None
-        style = self.html if parse_mode.lower() == "html" else self.markdown
 
         try:
             if os.path.exists(animation):
@@ -156,7 +181,7 @@ class SendAnimation(BaseClient):
                     url=animation
                 )
             else:
-                media = utils.get_input_media_from_file_id(animation, 10)
+                media = utils.get_input_media_from_file_id(animation, file_ref, 10)
 
             while True:
                 try:
@@ -167,24 +192,29 @@ class SendAnimation(BaseClient):
                             silent=disable_notification or None,
                             reply_to_msg_id=reply_to_message_id,
                             random_id=self.rnd_id(),
+                            schedule_date=schedule_date,
                             reply_markup=reply_markup.write() if reply_markup else None,
-                            **style.parse(caption)
+                            **self.parser.parse(caption, parse_mode)
                         )
                     )
                 except FilePartMissing as e:
                     self.save_file(animation, file_id=file.id, file_part=e.x)
                 else:
                     for i in r.updates:
-                        if isinstance(i, (types.UpdateNewMessage, types.UpdateNewChannelMessage)):
+                        if isinstance(
+                            i,
+                            (types.UpdateNewMessage, types.UpdateNewChannelMessage, types.UpdateNewScheduledMessage)
+                        ):
                             message = pyrogram.Message._parse(
                                 self, i.message,
                                 {i.id: i for i in r.users},
-                                {i.id: i for i in r.chats}
+                                {i.id: i for i in r.chats},
+                                is_scheduled=isinstance(i, types.UpdateNewScheduledMessage)
                             )
 
                             if unsave:
                                 document = message.animation or message.document
-                                document_id = utils.get_input_media_from_file_id(document.file_id).id
+                                document_id = utils.get_input_media_from_file_id(document.file_id, document.file_ref).id
 
                                 self.send(
                                     functions.messages.SaveGif(
