@@ -31,6 +31,7 @@ class SendLocation(BaseClient):
         longitude: float,
         disable_notification: bool = None,
         reply_to_message_id: int = None,
+        schedule_date: int = None,
         reply_markup: Union[
             "pyrogram.InlineKeyboardMarkup",
             "pyrogram.ReplyKeyboardMarkup",
@@ -59,6 +60,9 @@ class SendLocation(BaseClient):
             reply_to_message_id (``int``, *optional*):
                 If the message is a reply, ID of the original message
 
+            schedule_date (``int``, *optional*):
+                Date when the message will be automatically sent. Unix time.
+
             reply_markup (:obj:`InlineKeyboardMarkup` | :obj:`ReplyKeyboardMarkup` | :obj:`ReplyKeyboardRemove` | :obj:`ForceReply`, *optional*):
                 Additional interface options. An object for an inline keyboard, custom reply keyboard,
                 instructions to remove reply keyboard or to force a reply from the user.
@@ -66,8 +70,10 @@ class SendLocation(BaseClient):
         Returns:
             :obj:`Message`: On success, the sent location message is returned.
 
-        Raises:
-            RPCError: In case of a Telegram RPC error.
+        Example:
+            .. code-block:: python
+
+                app.send_location("me", 51.500729, -0.124583)
         """
         r = self.send(
             functions.messages.SendMedia(
@@ -82,14 +88,16 @@ class SendLocation(BaseClient):
                 silent=disable_notification or None,
                 reply_to_msg_id=reply_to_message_id,
                 random_id=self.rnd_id(),
+                schedule_date=schedule_date,
                 reply_markup=reply_markup.write() if reply_markup else None
             )
         )
 
         for i in r.updates:
-            if isinstance(i, (types.UpdateNewMessage, types.UpdateNewChannelMessage)):
+            if isinstance(i, (types.UpdateNewMessage, types.UpdateNewChannelMessage, types.UpdateNewScheduledMessage)):
                 return pyrogram.Message._parse(
                     self, i.message,
                     {i.id: i for i in r.users},
-                    {i.id: i for i in r.chats}
+                    {i.id: i for i in r.chats},
+                    is_scheduled=isinstance(i, types.UpdateNewScheduledMessage)
                 )
