@@ -16,10 +16,13 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-from .bots import *
+from .bots_and_keyboards import *
 from .inline_mode import *
 from .input_media import *
 from .input_message_content import *
+from .list import List
 from .messages_and_media import *
+from .object import Object
+from .authorization import *
 from .update import *
 from .user_and_chats import *
