@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -37,8 +37,9 @@ class Connection:
         4: TCPIntermediateO
     }
 
-    def __init__(self, dc_id: int, test_mode: bool, ipv6: bool, proxy: dict, mode: int = 1):
+    def __init__(self, dc_id: int, test_mode: bool, ipv6: bool, proxy: dict, mode: int = 3):
         self.dc_id = dc_id
+        self.test_mode = test_mode
         self.ipv6 = ipv6
         self.proxy = proxy
         self.address = DataCenter(dc_id, test_mode, ipv6)
@@ -59,7 +60,8 @@ class Connection:
                 self.connection.close()
                 time.sleep(1)
             else:
-                log.info("Connected! DC{} - IPv{} - {}".format(
+                log.info("Connected! {} DC{} - IPv{} - {}".format(
+                    "Test" if self.test_mode else "Production",
                     self.dc_id,
                     "6" if self.ipv6 else "4",
                     self.mode.__name__
