@@ -70,12 +70,14 @@ class Session:
         64: "[64] invalid container"
     }
 
-    def __init__(self,
-                 client: pyrogram,
-                 dc_id: int,
-                 auth_key: bytes,
-                 is_media: bool = False,
-                 is_cdn: bool = False):
+    def __init__(
+        self,
+        client: pyrogram,
+        dc_id: int,
+        auth_key: bytes,
+        is_media: bool = False,
+        is_cdn: bool = False
+    ):
         if not Session.notice_displayed:
             print("Pyrogram v{}, {}".format(__version__, __copyright__))
             print("Licensed under the terms of the " + __license__, end="\n\n")
@@ -113,7 +115,12 @@ class Session:
 
     def start(self):
         while True:
-            self.connection = Connection(self.dc_id, self.client.test_mode, self.client.ipv6, self.client.proxy)
+            self.connection = Connection(
+                self.dc_id,
+                self.client.storage.test_mode(),
+                self.client.ipv6,
+                self.client.proxy
+            )
 
             try:
                 self.connection.connect()
@@ -431,10 +438,10 @@ class Session:
             if retries == 0:
                 raise e from None
 
-            (log.warning if retries < 3 else log.info)(
-                "{}: {} Retrying {}".format(
-                    Session.MAX_RETRIES - retries,
-                    datetime.now(), type(data)))
+            (log.warning if retries < 2 else log.info)(
+                "[{}] Retrying {} due to {}".format(
+                    Session.MAX_RETRIES - retries + 1,
+                    data.QUALNAME, e))
 
             time.sleep(0.5)
             return self.send(data, retries - 1, timeout)
